@@ -1,5 +1,6 @@
 import { css } from '@emotion/css';
 import * as React from 'react';
+import type { JSX } from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
 import { InlineField, Input, useStyles2 } from '@grafana/ui';
@@ -10,10 +11,11 @@ interface Props {
   placeholder?: string;
   width?: number;
   id?: string | undefined;
+  tooltip?: string | undefined;
   onChange: (value: string) => void;
 }
 
-export const AssertionEditorRow = ({ value, label, placeholder, width, id, onChange }: Props): JSX.Element => {
+export const AssertionEditorRow = ({ value, label, placeholder, width, id, tooltip, onChange }: Props): JSX.Element => {
   const styles = useStyles2(getStyles);
 
   const onChangeInternal = (event: React.FormEvent<HTMLInputElement>) => {
@@ -23,7 +25,7 @@ export const AssertionEditorRow = ({ value, label, placeholder, width, id, onCha
 
   return (
     <div className={styles.assertionEditorRow}>
-      <InlineField label={label} labelWidth={16} htmlFor={id}>
+      <InlineField label={label} labelWidth={22} htmlFor={id} tooltip={tooltip}>
         <Input width={width || 30} id={id} value={value || ''} onChange={onChangeInternal} placeholder={placeholder} />
       </InlineField>
     </div>
