@@ -1,10 +1,8 @@
-import { ReactNode } from 'react';
-import { Path, UseFormReturn } from 'react-hook-form';
-
-import { SelectableValue } from '@grafana/data';
+import { Path } from 'react-hook-form';
 
 import {
   BitbucketRepositoryConfig,
+  ConnectionSpec,
   GitHubRepositoryConfig,
   GitLabRepositoryConfig,
   GitRepositoryConfig,
@@ -16,26 +14,6 @@ import {
 export type RepositoryType = RepositorySpec['type'];
 export type RepoWorkflows = RepositorySpec['workflows'];
 
-// Field configuration interface
-export interface RepositoryFieldData {
-  label: string;
-  type: 'text' | 'secret' | 'switch' | 'select' | 'checkbox' | 'custom' | 'component' | 'number';
-  description?: string | ReactNode;
-  placeholder?: string;
-  path?: Path<RepositoryFormData>; // Optional nested field path, e.g., 'sync.intervalSeconds'
-  validation?: {
-    required?: boolean | string;
-    message?: string;
-    validate?: (value: unknown) => boolean | string;
-  };
-  defaultValue?: SelectableValue<string> | string | boolean;
-  options?: Array<SelectableValue<string>>;
-  multi?: boolean;
-  allowCustomValue?: boolean;
-  hidden?: boolean;
-  content?: (setValue: UseFormReturn<RepositoryFormData>['setValue']) => ReactNode; // For custom fields
-}
-
 export type RepositoryFormData = Omit<RepositorySpec, 'workflows' | RepositorySpec['type']> &
   BitbucketRepositoryConfig &
   GitRepositoryConfig &
@@ -47,17 +25,23 @@ export type RepositoryFormData = Omit<RepositorySpec, 'workflows' | RepositorySp
     enablePushToConfiguredBranch: boolean;
     // top-level inline secure value
     token?: string;
+    // GitHub App connection name (when using app-based auth instead of PAT)
+    connectionName?: string;
   };
 
 export type RepositorySettingsField = Path<RepositoryFormData>;
 
-// Section configuration
-export interface RepositorySection {
-  name: string;
-  id: string;
-  hidden?: boolean;
-  fields: RepositorySettingsField[];
-}
+// Connection type definition - extracted from API client
+export type ConnectionType = ConnectionSpec['type'];
+
+export type ConnectionFormData = {
+  type: ConnectionType;
+  title: string;
+  description: string;
+  appID: string;
+  installationID: string;
+  privateKey?: string;
+};
 
 // Added to DashboardDTO to help editor
 export interface ProvisioningPreview {
@@ -83,7 +67,7 @@ export type AuthorInfo = {
 
 export type FileDetails = {
   path: string;
-  size: string;
+  size?: string;
   hash: string;
 };
 
@@ -98,3 +82,31 @@ export interface StatusInfo {
   title?: string;
   message?: string | string[];
 }
+
+// Tree view types for combined Resources/Files view
+export type ItemType = 'Folder' | 'File' | 'Dashboard';
+export type SyncStatus = 'synced' | 'pending';
+
+export interface TreeItem {
+  title: string;
+  type: ItemType;
+  path: string;
+  level: number;
+  children: TreeItem[];
+  resourceName?: string;
+  hash?: string;
+  status?: SyncStatus;
+  hasFile?: boolean;
+}
+
+export interface FlatTreeItem {
+  item: TreeItem;
+  level: number;
+}
+
+// External repository from the provider (e.g., GitHub)
+export interface ExternalRepository {
+  name?: string;
+  owner?: string;
+  url?: string;
+}
